@@ -157,7 +157,7 @@ class UpgradeSourceCode(Command):
         files = []
         for f in os.listdir(os.path.dirname(os.path.abspath(__file__))):
             q = os.path.join('setup', f)
-            if f.endswith('.py') and f not in ('linux-installer.py',) and not os.path.isdir(q):
+            if f.endswith('.py') and f != 'linux-installer.py' and not os.path.isdir(q):
                 files.append(q)
         for path in checkable_python_files(self.SRC):
             q = path.replace(os.sep, '/')
