@@ -7,6 +7,7 @@ __docformat__ = 'restructuredtext en'
 
 import datetime
 import os
+import unittest
 from io import BytesIO
 from time import time
 
@@ -644,7 +645,7 @@ class ReadingTest(BaseTest):
                     except Exception:
                         pass
                     return x
-                if field not in {'#series_index'}:
+                if field != '#series_index':
                     v = pmi.get_standard_metadata(field)
                     self.assertTrue(v is None or isinstance(v, dict))
                     self.assertEqual(f(mi.get_standard_metadata(field, False)), f(v),
@@ -834,15 +835,36 @@ class ReadingTest(BaseTest):
 
         db = self.init_cache(self.library_path)
         db.create_custom_column('mult', 'CC1', 'composite', True, display={'composite_template': 'b,a,c'})
+        db.create_custom_column('pages', 'Pages', 'int', False)
 
         # need an empty metadata object to pass to the formatter
         db = self.init_legacy(self.library_path)
+        db.new_api.set_field('#pages', {1: '11', 2: '22', 3: '33'})
         mi = db.get_metadata(1)
 
+        # test width_from_pages
+        v = formatter.safe_format('{#pages:width_from_pages(2,2,0.5)}', {}, 'TEMPLATE ERROR', mi)
+        self.assertEqual(v, '1.0')
+        v = formatter.safe_format('{#pages:width_from_pages()}', {}, 'TEMPLATE ERROR', mi)
+        self.assertEqual(int(float(v) * 1000), 26)
+        v = formatter.safe_format('{#pages:width_from_pages(1500)}', {}, 'TEMPLATE ERROR', mi)
+        self.assertEqual(int(float(v) * 1000), 26)
+        v = formatter.safe_format('{#pages:width_from_pages(1500,2)}', {}, 'TEMPLATE ERROR', mi)
+        self.assertEqual(int(float(v) * 1000), 26)
+        v = formatter.safe_format('{#pages:width_from_pages(1500,2,11)}', {}, 'TEMPLATE ERROR', mi)
+        self.assertEqual(int(float(v) * 1000), 26)
+
         # test counting books matching the search
         v = formatter.safe_format('program: book_count("series:true", 0)', {}, 'TEMPLATE ERROR', mi)
         self.assertEqual(v, '2')
 
+        # test python templates
+        v = formatter.safe_format('python:\ndef evaluate(book, ctx): return "x"', {}, 'TEMPLATE ERROR', mi)
+        if os.environ.get('CALIBRE_ALLOW_PYTHON_TEMPLATES', '1') == '1':
+            self.assertEqual(v, 'x')
+        else:
+            self.assertTrue(v.startswith('TEMPLATE ERROR'))
+
         # test counting books when none match the search
         v = formatter.safe_format('program: book_count("series:afafaf", 0)', {}, 'TEMPLATE ERROR', mi)
         self.assertEqual(v, '0')
@@ -888,6 +910,7 @@ class ReadingTest(BaseTest):
         self.assertEqual(set(v.split(',')), {'4', '6'})
     # }}}
 
+    @unittest.skipIf(os.environ.get('CALIBRE_ALLOW_PYTHON_TEMPLATES', '1') != '1', 'Python templates disallowed')
     def test_python_templates(self):  # {{{
         from calibre.ebooks.metadata.book.formatter import SafeFormat
         formatter = SafeFormat()
