@@ -161,13 +161,22 @@ def border_to_css(edge, style, css):
 
 def read_indent(parent, dest, XPath, get):
     padding_left = padding_right = text_indent = inherit
+    is_rtl = getattr(dest, 'bidi', False)
     for indent in XPath('./w:ind')(parent):
-        l, lc = get(indent, 'w:left'), get(indent, 'w:leftChars')
+        start = get(indent, 'w:start')
+        end = get(indent, 'w:end')
+        startChars = get(indent, 'w:startChars')
+        endChars = get(indent, 'w:endChars')
+        left, leftChars, right, rightChars = start, startChars, end, endChars
+        if is_rtl and is_rtl is not inherit:
+            # TODO: For inherit we should be using textDirection from sectPr
+            left, leftChars, right, rightChars = end, endChars, start, startChars
+        l, lc = left or get(indent, 'w:left'), leftChars or get(indent, 'w:leftChars')
         pl = simple_float(lc, 0.01) if lc is not None else simple_float(l, 0.05) if l is not None else None
         if pl is not None:
             padding_left = '{:.3g}{}'.format(pl, 'em' if lc is not None else 'pt')
 
-        r, rc = get(indent, 'w:right'), get(indent, 'w:rightChars')
+        r, rc = right or get(indent, 'w:right'), rightChars or get(indent, 'w:rightChars')
         pr = simple_float(rc, 0.01) if rc is not None else simple_float(r, 0.05) if r is not None else None
         if pr is not None:
             padding_right = '{:.3g}{}'.format(pr, 'em' if rc is not None else 'pt')
