@@ -288,7 +288,7 @@ class MobiWriter:
         # 0x58 - 0x5b : Format version
         # 0x5c - 0x5f : First image record number
         record0.write(pack(b'>II',
-            6, first_image_record if first_image_record else len(self.records)))
+            6, first_image_record or len(self.records)))
 
         # 0x60 - 0x63 : First HUFF/CDIC record number
         # 0x64 - 0x67 : Number of HUFF/CDIC records
@@ -400,8 +400,7 @@ class MobiWriter:
         self.records.append(self.kf8.record0)
         self.records.extend(self.kf8.records[1:])
 
-        first_image_record = (first_image_record if first_image_record else
-                len(self.records))
+        first_image_record = (first_image_record or len(self.records))
 
         header_fields = {k:getattr(self.kf8, k) for k in HEADER_FIELDS}
 
