@@ -894,7 +894,7 @@ class EditorWidget(QTextEdit, LineEditECM):  # {{{
                 if data_dir:
                     path = os.path.relpath(path, base).replace(os.sep, '/')
                     d.url.setText(path)
-        b.clicked.connect(lambda: cf())
+        b.clicked.connect(cf)
         d.brdf = b = QPushButton(_('&Data file'))
         b.clicked.connect(lambda: cf(True))
         b.setToolTip(_('A relative link to a data file associated with this book'))
