@@ -12,9 +12,9 @@ from qt.core import (
     QAction,
     QApplication,
     QColor,
+    QDialog,
     QIcon,
     QImage,
-    QInputDialog,
     QMainWindow,
     QMenu,
     QPainter,
@@ -263,11 +263,7 @@ class Editor(QMainWindow):
         for name in names:
             m.addAction(name, partial(self.insert_tag, name))
         m.addSeparator()
-        m.addAction(_('Add a tag to this menu'), self.add_insert_tag)
-        if names:
-            m = m.addMenu(_('Remove from this menu'))
-            for name in names:
-                m.addAction(name, partial(self.remove_insert_tag, name))
+        m.addAction(_('Manage the entries in this menu'), self.manage_insert_tags)
 
     def insert_tag(self, name):
         self.editor.insert_tag(name)
@@ -280,24 +276,12 @@ class Editor(QMainWindow):
         tprefs['insert_tag_mru'] = mru
         self._build_insert_tag_button_menu()
 
-    def add_insert_tag(self):
-        name, ok = QInputDialog.getText(self, _('Name of tag to add'), _(
-            'Enter the name of the tag'))
-        if ok:
-            mru = tprefs['insert_tag_mru']
-            mru.insert(0, name)
-            tprefs['insert_tag_mru'] = mru
+    def manage_insert_tags(self):
+        from calibre.gui2.tweak_book.widgets import ManageTagList
+        d = ManageTagList(self)
+        if d.exec() == QDialog.DialogCode.Accepted:
             self._build_insert_tag_button_menu()
 
-    def remove_insert_tag(self, name):
-        mru = tprefs['insert_tag_mru']
-        try:
-            mru.remove(name)
-        except ValueError:
-            pass
-        tprefs['insert_tag_mru'] = mru
-        self._build_insert_tag_button_menu()
-
     def set_request_completion(self, callback=None, doc_name=None):
         self.editor.request_completion = callback
         self.editor.completion_doc_name = doc_name
