@@ -268,9 +268,9 @@ class AuthController:
         return cookie and validate_nonce(self.key_order, cookie, path, self.secret) and not is_nonce_stale(cookie, self.max_age_seconds)
 
     def do_http_auth(self, data, endpoint):
-        ban_key = data.remote_addr, data.forwarded_for
+        ban_key = data.remote_addr
         if self.ban_list.is_banned(ban_key):
-            raise HTTPForbidden('Too many login attempts', log=f'Too many login attempts from: {ban_key if data.forwarded_for else data.remote_addr}')
+            raise HTTPForbidden('Too many login attempts', log=f'Too many login attempts from: {data.remote_addr}')
         auth = data.inheaders.get('Authorization')
         nonce_is_stale = False
         log_msg = None
