@@ -221,7 +221,7 @@ def book_fmt(ctx, rd, library_id, db, book_id, fmt):
             set_metadata(dest, mi, fmt)
             dest.seek(0)
 
-    cd = rd.query.get('content_disposition', 'attachment')
+    cd = sanitize_content_disposition(rd.query.get('content_disposition', 'attachment'))
     rd.outheaders['Content-Disposition'] = (
         f'''{cd}; filename="{book_filename(rd, book_id, mi, fmt)}"; filename*=utf-8''{book_filename(rd, book_id, mi, fmt, as_encoded_unicode=True)}''')
 
@@ -522,8 +522,12 @@ def set_note(ctx, rd, field, item_id, library_id):
     return srv_html
 
 
+def sanitize_content_disposition(x: str) -> str:
+    return re.sub(r'[^a-zA-Z0-9./-]', '-', x)
+
+
 def data_file(rd, fname, path, stat_result):
-    cd = rd.query.get('content_disposition', 'attachment')
+    cd = sanitize_content_disposition(rd.query.get('content_disposition', 'attachment'))
     rd.outheaders['Content-Disposition'] = (
         f'''{cd}; filename="{fname_for_content_disposition(fname)}"; filename*=utf-8''{fname_for_content_disposition(fname, as_encoded_unicode=True)}''')
     return rd.filesystem_file_with_custom_etag(share_open(path, 'rb'), stat_result.st_dev, stat_result.st_ino, stat_result.st_size, stat_result.st_mtime)
